@@ -1,5 +1,8 @@
 from .x1dints import *
-from .eureka import *
+from .eureka_txt import *
+from .eureka_specdata import *
+from .eureka_lcdata import *
+from .eureka_channels import *
 from .rainbow_npy import *
 from .rainbow_FITS import *
 from .text import *
@@ -35,44 +38,46 @@ def guess_reader(filepath, format=None):
     format : str, None
         The file format to use.
     """
-    import fnmatch, glob
+
     from ...imports import expand_filenames
+    from fnmatch import fnmatch
+    import glob
 
     # get all the possible filenames (= expand wildcard)
     filenames = expand_filenames(filepath)
+    f = filenames[0]
 
     # if format='abcdefgh', return the `from_abcdefgh` function
     if format is not None:
         return available_readers[f"from_{format}"]
     # does it look like a .rainbow.npy chromatic file?
-    elif fnmatch.fnmatch(filenames[0], "*.rainbow.npy"):
+    elif fnmatch(f, "*.rainbow.npy"):
         return from_rainbow_npy
-    elif fnmatch.fnmatch(filepath.lower(), "*.rainbow.fits") or fnmatch.fnmatch(
-        filepath.lower(), "*.rainbow.fit"
-    ):
+    elif fnmatch(f.lower(), "*.rainbow.fits") or fnmatch(f.lower(), "*.rainbow.fit"):
         return from_rainbow_FITS
     # does it look like a .rainbow.npy chromatic file?
-    elif fnmatch.fnmatch(filenames[0], "*order*.npy"):
+    elif fnmatch(f, "*order*.npy"):
         return from_espinoza
     # does it look like a STScI x1dints.fits file?
-    elif fnmatch.fnmatch(filenames[0], "*x1dints.fits") or fnmatch.fnmatch(
-        filenames[0], "*extract_1d.fits"
-    ):
+    elif fnmatch(f, "*x1dints.fits") or fnmatch(f, "*extract_1d.fits"):
         return from_x1dints
-    # does it look like an Eureka! save file?
-    elif (
-        fnmatch.fnmatch(filenames[0], "*S3_*_Save.dat")
-        or fnmatch.fnmatch(filenames[0], "*S3_*_Save.h5")
-        or fnmatch.fnmatch(filenames[0], "*S3_*_Save.txt")
-    ):
-        return from_eureka
-    elif fnmatch.fnmatch(filenames[0], "*.txt") or fnmatch.fnmatch(
-        filenames[0], "*.csv"
-    ):
+    # does it look like an Eureka! S3 text file?
+    elif fnmatch(f, "*S3_*_Save.dat") or fnmatch(f, "*S3_*_Save.txt"):
+        return from_eureka_SpecData
+    # does it look like an Eureka! S3 SpecData hdf5 file?
+    elif fnmatch(f, "*S3_*_SpecData.h5"):
+        return from_eureka_S3
+    # does it look like an Eureka! S4 SpecData hdf5 file?
+    elif fnmatch(f, "*S4_*_SpecData.h5"):
+        return from_eureka_SpecData
+    # does it look like an Eureka! S4 LCData hdf5 file?
+    elif fnmatch(f, "*S4_*_LCData.h5"):
+        return from_eureka_S4
+    elif fnmatch(f, "*S5_*_Table_Save_*.txt"):
+        return from_eureka_S5
+    elif fnmatch(f, "*.txt") or fnmatch(f, "*.csv"):
         return from_text
-    elif fnmatch.fnmatch(filenames[0], "*e92-1d.fits") or fnmatch.fnmatch(
-        filenames[0], "*e92-1d.fits.fz"
-    ):
+    elif fnmatch(f, "*e92-1d.fits") or fnmatch(f, "*e92-1d.fits.fz"):
         return from_nres
     else:
         raise RuntimeError(f"🌈 Failed to guess a good reader for {filenames}.")
