@@ -12,10 +12,14 @@ def imshow(
     t_unit="day",
     colorbar=True,
     aspect="auto",
+    mask_ok=True,
+    color_ok="tomato",
+    alpha_ok=0.8,
     **kw,
 ):
     """
-    imshow flux as a function of time (x = time, y = wavelength, color = flux).
+    Paint a 2D image of flux as a function of time and wavelength,
+    using `plt.imshow` where pixels will have constant size.
 
     Parameters
     ----------
@@ -32,6 +36,12 @@ def imshow(
         Should we include a colorbar?
     aspect : str
         What aspect ratio should be used for the imshow?
+    mask_ok : bool
+        Should we mark which data are not OK?
+    color_ok : str
+        The color to be used for masking data points that are not OK.
+    alpha_ok : float
+        The transparency to be used for masking data points that are not OK.
     kw : dict
         All other keywords will be passed on to `plt.imshow`,
         so you can have more detailed control over the plot
@@ -58,6 +68,7 @@ def imshow(
         wmax = self.wavelength_upper[-1].to_value(w_unit)
     except AttributeError:
         wmin, wmax = None, None
+
     if (self.wscale == "linear") and (wmin is not None) and (wmax is not None):
         wlower, wupper = wmin, wmax
         wlabel = f"{self._wave_label} ({w_unit.to_string('latex_inline')})"
@@ -133,13 +144,15 @@ def imshow(
             return self.fluxlike.get(k, None)
 
     if xaxis.lower()[0] == "t":
-        self._imshow_extent = [tlower, tupper, wupper, wlower]
+        self.metadata["_imshow_extent"] = [tlower, tupper, wupper, wlower]
         xlabel, ylabel = tlabel, wlabel
         z = get_2D(quantity)
+        ok = get_2D("ok")
     elif xaxis.lower()[0] == "w":
-        self._imshow_extent = [wlower, wupper, tupper, tlower]
+        self.metadata["_imshow_extent"] = [wlower, wupper, tupper, tlower]
         xlabel, ylabel = wlabel, tlabel
         z = get_2D(quantity).T
+        ok = get_2D("ok").T
     else:
         warnings.warn(
             "Please specify either `xaxis='time'` or `xaxis='wavelength'` for `.plot()`"
@@ -150,9 +163,31 @@ def imshow(
     imshow_kw.update(**kw)
     with quantity_support():
         plt.sca(ax)
+
+        # create an overlaying mask of which data are OK or not
+        if mask_ok:
+            okimshow_kw = dict(**imshow_kw)
+            okimshow_kw.update(
+                cmap=one2another(
+                    bottom=color_ok,
+                    top=color_ok,
+                    alpha_bottom=alpha_ok,
+                    alpha_top=0,
+                ),
+                zorder=10,
+                vmin=0,
+                vmax=1,
+            )
+            plt.imshow(
+                ok,
+                extent=self.metadata["_imshow_extent"],
+                aspect=aspect,
+                origin="upper",
+                **okimshow_kw,
+            )
         plt.imshow(
             z,
-            extent=self._imshow_extent,
+            extent=self.metadata["_imshow_extent"],
             aspect=aspect,
             origin="upper",
             **imshow_kw,
@@ -164,4 +199,5 @@ def imshow(
                 ax=ax,
                 label=u.Quantity(z).unit.to_string("latex_inline"),
             )
+
     return ax
