@@ -14,6 +14,7 @@ def plot_lightcurves(
     vmin=None,
     vmax=None,
     errorbar=False,
+    minimum_acceptable_ok=1,
     plotkw={},
     errorbarkw={},
     textkw={},
@@ -42,6 +43,9 @@ def plot_lightcurves(
         The maximum value to use for the wavelength colormap.
     errorbar : boolean
         Should we plot errorbars?
+    minimum_acceptable_ok : float
+        The smallest value of `ok` that will still be included.
+        (1 for perfect data, 1e-10 for everything but terrible data, 0 for all data)
     plotkw : dict
         A dictionary of keywords passed to `plt.plot`
         so you can have more detailed control over the plot
@@ -83,7 +87,7 @@ def plot_lightcurves(
 
     w_unit, t_unit = u.Unit(w_unit), u.Unit(t_unit)
 
-    min_time = np.nanmin(self.time)
+    min_time = np.nanmin(self.time.to_value(t_unit))
 
     # make sure ax is set up
     if ax is None:
@@ -111,13 +115,17 @@ def plot_lightcurves(
         for i, w in enumerate(self.wavelength):
 
             # grab the quantity and yerr for this particular wavelength
-            quan = self.fluxlike[quantity][i, :]
-            uncertainty = self.fluxlike["uncertainty"][i, :]
+            t, y, sigma = self.get_ok_data_for_wavelength(
+                i, minimum_acceptable_ok=minimum_acceptable_ok
+            )
 
-            if np.any(np.isfinite(quan)):
+            if np.any(np.isfinite(y)):
+
+                plot_x = t.to_value(t_unit)
 
                 # add an offset to this quantity
-                plot_quan = -i * spacing + quan
+                plot_y = -i * spacing + u.Quantity(y).value
+                plot_sigma = u.Quantity(sigma).value
 
                 # get the color for this quantity
                 color = self.get_wavelength_color(w)
@@ -134,19 +142,19 @@ def plot_lightcurves(
 
                 if errorbar:
                     plt.errorbar(
-                        self.time.to(t_unit),
-                        plot_quan,
-                        yerr=uncertainty,
+                        plot_x,
+                        plot_y,
+                        yerr=plot_sigma,
                         **this_errorbarkw,
                     )
-                plt.plot(self.time.to(t_unit), plot_quan, **this_plotkw)
+                plt.plot(plot_x, plot_y, **this_plotkw)
 
                 # add text labels next to each quantity plot
                 this_textkw = dict(va="bottom", color=color)
                 this_textkw.update(**textkw)
                 plt.annotate(
-                    f"{w.to(w_unit).value:.2f} {w_unit.to_string('latex_inline')}",
-                    (min_time, np.median(plot_quan) - 0.5 * spacing),
+                    f"{w.to_value(w_unit):.2f} {w_unit.to_string('latex_inline')}",
+                    (min_time, np.median(plot_y) - 0.5 * spacing),
                     **this_textkw,
                 )
 
