@@ -19,17 +19,18 @@ def guess_writer(filepath, format=None):
     format : str, None
         The file format to use.
     """
-    import fnmatch, glob
+    from fnmatch import fnmatch
+    import glob
 
     # if format='abcdefgh', return the `to_abcdefgh` function
     if format is not None:
         return available_writers[f"to_{format}"]
     # does it look like a .rainbow.npy chromatic file?
-    elif fnmatch.fnmatch(filepath, "*.rainbow.npy"):
+    elif fnmatch(filepath, "*.rainbow.npy"):
         return to_rainbow_npy
-    elif fnmatch.fnmatch(filepath.lower(), "*.rainbow.fits") or fnmatch.fnmatch(
+    elif fnmatch(filepath.lower(), "*.rainbow.fits") or fnmatch(
         filepath.lower(), "*.rainbow.fit"
     ):
         return to_rainbow_FITS
-    elif fnmatch.fnmatch(filepath, "*.txt") or fnmatch.fnmatch(filepath, "*.csv"):
+    elif fnmatch(filepath, "*.txt") or fnmatch(filepath, "*.csv"):
         return to_text
