@@ -80,15 +80,13 @@ def test_align_wavelengths_with_not_ok_data(visualize=False):
             dt=20 * u.minute,
         )
         r.fluxlike["ok"] = np.random.uniform(size=r.shape) < ok_fraction
-        cautious = r.align_wavelengths(ok_threshold=1)
-        carefree = r.align_wavelengths(ok_threshold=0)
+        cautious = r.align_wavelengths(minimum_acceptable_ok=1)
+        carefree = r.align_wavelengths(minimum_acceptable_ok=0)
         if visualize:
             cautious.imshow_quantities()
             plt.suptitle(ok_fraction)
             carefree.imshow_quantities()
             plt.suptitle(ok_fraction)
 
-        assert np.all((cautious.ok == 1) | (cautious.ok == 0))
-
         if np.any(r.ok == 0):
             assert np.any((carefree.ok != 1) & (carefree.ok != 0))
