@@ -30,8 +30,19 @@ def test_guess_readers():
 
     assert guess_reader("some-neat-file.rainbow.npy") == from_rainbow_npy
     assert guess_reader("some-neat-file-x1dints.fits") == from_x1dints
-    assert guess_reader("S3_neat-planet_Save.txt") == from_eureka
-    assert guess_reader("some-weird-file.txt") == from_text
+
+    # eureka readers
+    assert guess_reader("S3_wasp39b_ap6_bg7_SpecData.h5") == from_eureka_S3
+    assert guess_reader("S4_wasp39b_ap6_bg7_LCData.h5") == from_eureka_S4
+    assert (
+        guess_reader(
+            [
+                "S5_wasp39b_ap6_bg7_Table_Save_ch0.txt",
+                "S5_wasp39b_ap6_bg7_Table_Save_ch1.txt",
+            ]
+        )
+        == from_eureka_S5
+    )
 
 
 def test_guess_writers():
